#ifndef SWITCHWIDGET_H
#define SWITCHWIDGET_H

#include "gmc-common_global.h"
#include "switchdefines.h"
#include <QWidget>
#include <QCheckBox>

namespace Ui {
    class SwitchWidget;
}

class GMC_COMMON_SHARED_EXPORT SwitchWidget : public QWidget
{
    Q_OBJECT
public:
    explicit SwitchWidget(const QString &id,
                          const QString &name,
                          const QString &longname,
                          const QString &tooltip,
                          const QString &script,
                          QWidget *parent = nullptr);

    virtual ~SwitchWidget();
    void setGroup(const SwitchGroup &type);
    void setGrayState(bool gray);
    void setRebootCase(const bool rebootOnEnable, const bool rebootOnDisable);
    void setExtraText(const QString &extra);
    void setChecked(bool state);
    void setCheckedForced(bool state);

    void setSlaveId(const QString &slaveId);

    bool isChecked() const;
    void reset();
    void blockControlSignals(const bool block) const;
    void setControlEnabled(const bool enabled) const;
    bool needReboot() const;
    const QString getScript() const;
    const QString getId() const;
    SwitchGroup getGroup() const;    
    const QString getSlaveId() const;
    bool haveSlave() const;

signals:
    void needApply(const bool needApply);
    void extraButtonClicked();
    void forceCheckSlave(bool /*state*/);

public slots:

private:
    //TODO change type of id to int
    QString m_id;
    QString m_name; //NOTE unused now
    QString m_longname;
    QString m_tooltip;
    QString m_script;
    QString m_extratext;
    QString m_slaveId = QString();
    SwitchGroup m_group;
    bool m_permDisabled = false;
    bool m_checkState = false;
    bool m_rebootOnEnable = false;
    bool m_rebootOnDisable = false;

    Ui::SwitchWidget *m_ui;

private slots:
    void checkBoxClicked(const bool checked);
};

#endif // SWITCHWIDGET_H
